#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

from zope.component import adapter
from zope.interface import implementer

from schooltool.app.interfaces import ISchoolToolApplication
from schooltool.schoolyear.interfaces import ISchoolYear
from schooltool.courseinfo.courseinfo import COURSEINFO_ROOT_KEY
from schooltool.courseinfo.courseinfo import CourseInfoContainer
from schooltool.courseinfo.courseinfo import CourseInfoSchoolYear
from schooltool.courseinfo.courseinfo import CourseInfoSchoolYearContainer
from schooltool.courseinfo.courseinfo import CurrentCourseInfoContainer
from schooltool.courseinfo.courseinfo import ProposedCourseInfoContainer

import interfaces

@adapter(ISchoolToolApplication)
@implementer(interfaces.ICourseInfoRoot)
def getCourseInfoRoot(app):
    if COURSEINFO_ROOT_KEY not in app:
        return None
    return app[COURSEINFO_ROOT_KEY]

@adapter(interfaces.ICourseInfoRoot)
@implementer(interfaces.ICourseInfoSchoolYearContainer)
def getCourseInfoSchoolYearContainer(root):
    if 'schoolyears' not in root:
        root['schoolyears'] = CourseInfoSchoolYearContainer()
    return root['schoolyears']

@adapter(ISchoolYear)
@implementer(interfaces.ICourseInfoSchoolYear)
def getCourseInfoSchoolYear(year):
    root = interfaces.ICourseInfoRoot(ISchoolToolApplication(None))
    schoolyears = interfaces.ICourseInfoSchoolYearContainer(root)
    if year.__name__ not in schoolyears:
        obj = CourseInfoSchoolYear()
        schoolyears[year.__name__] = obj 
        obj['current_courses'] = CurrentCourseInfoContainer()
        obj['proposed_courses'] = ProposedCourseInfoContainer()
    return schoolyears[year.__name__]

@adapter(interfaces.ICourseInfoSchoolYear)
@implementer(interfaces.ICurrentCourseInfoContainer)
def getCurrentCourseInfoContainer(year):
    return year['current_courses']

@adapter(interfaces.ICourseInfoSchoolYear)
@implementer(interfaces.IProposedCourseInfoContainer)
def getProposedCourseInfoContainer(year):
    return year['proposed_courses']


