#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Forms for CourseInfo
"""


from zope.browserpage.viewpagetemplatefile import ViewPageTemplateFile
from zope.component import adapts
from zope.traversing.browser.absoluteurl import absoluteURL

from z3c.form import form, field, button
from z3c.form.converter import BaseDataConverter
from z3c.form.interfaces import ITextAreaWidget

from schooltool.courseinfo.courseinfo import ProposedCourseInfo
from schooltool.courseinfo import interfaces

from schooltool.courseinfo import CourseinfoMessage as _


class CustomListDataConverter(BaseDataConverter):
    """A special data converter for iso enums."""

    adapts(interfaces.CourseInfoValueList, ITextAreaWidget)

    def toWidgetValue(self, value):
        """See interfaces.IDataConverter"""
        if value is self.field.missing_value:
            return u''
        return unicode('\n'.join(value))

    def toFieldValue(self, value):
        """See interfaces.IDataConverter"""
        if value == u'':
            return self.field.missing_value
        lines = filter(None, [s.strip() for s in unicode(value).splitlines()])
        if not lines:
            return self.field.missing_value
        field_value = []
        for line in lines:
            field_value.append(line)
        return field_value


class ProposedCourseInfoAddView(form.AddForm):
    """A view for adding a new courseinfo."""
    label = _("Add new courseinfo")
    template = ViewPageTemplateFile('templates/add_edit_courseinfo.pt')

    fields = field.Fields(interfaces.IProposedCourseInfo)
    fields = fields.select('course_id', 'title', 'description',
                           'start_grade', 'end_grade', 'duration',
                           'credits', 'elective', 'division', 'cluster',
                           'pathway', 'requirements', 'government_id',
                           'credit_codes', 'supervisor', 'planning_information',
                           'weight', 'lab_fee', 'notes', 'prerequisite',
                           'outcomes')

    def updateActions(self):
        super(ProposedCourseInfoAddView, self).updateActions()
        self.actions['add'].addClass('button-ok')
        self.actions['cancel'].addClass('button-cancel')

    @button.buttonAndHandler(_('Add'), name='add')
    def handleAdd(self, action):
        data, errors = self.extractData()
        if errors:
            self.status = self.formErrorsMessage
            return
        obj = self.createAndAdd(data)
        if obj is not None:
            # mark only as finished if we get the new object
            self._finishedAdd = True

    @button.buttonAndHandler(_("Cancel"))
    def handle_cancel_action(self, action):
        url = absoluteURL(self.context, self.request)
        self.request.response.redirect(url)

    def create(self, data):
        courseinfo = ProposedCourseInfo(data['course_id'], data['title'],
                                        data['description'], data['start_grade'],
                                        data['end_grade'],
                                        data['duration'], data['credits'],
                                        data['elective'], data['division'],
                                        cluster=data['cluster'], pathway=data['pathway'],
                                        requirements=data['requirements'],
                                        government_id=data['government_id'],
                                        credit_codes=data['credit_codes'],
                                        supervisor=data['supervisor'],
                                        planning_information=data['planning_information'],
                                        weight=data['weight'], lab_fee=data['lab_fee'],
                                        notes=data['notes'], outcomes=data['outcomes'],
                                        prerequisite=data['prerequisite'])
        return courseinfo

    def add(self, courseinfo):
        """Add the CourseInfo to the container."""
        #chooser = INameChooser(self.context)
        #name = chooser.chooseName('', activity)
        # TODO: implement NameChooser for CourseInfo

        name = courseinfo.course_id
        if name in self.context:
            count=1
            while (name+'-'+str(count)) in self.context:
                count+=1
            name = name + '-' + str(count)

        self.context[name] = courseinfo
        return courseinfo

    def nextURL(self):
        return absoluteURL(self.context, self.request)

