#
# SchoolTool - common information systems platform for school administration
# Copyright (c) 2005 Shuttleworth Foundation
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
"""
Unit tests for course and section implementations.
"""
from zope.container.interfaces import IContainer, IContained
from zope.container.constraints import contains, containers
from zope.interface import Interface
from zope.schema import TextLine, Text, Int, Dict, List, Date, Float, Bool

from schooltool.courseinfo import CourseinfoMessage as _


class ICourseInfoRoot(IContainer):
    """The interface for the root container of schooltool.courseinfo."""


class ICourseInfoSchoolYearContainer(IContainer):
    """The intercafe for the container of CourseInfoSchoolYear objects."""

    contains('schooltool.courseinfo.interfaces.ICourseInfoSchoolYear')
    containers(ICourseInfoRoot)


class ICourseInfoSchoolYear(IContainer):
    """The interface for the CourseInfoSchoolYear container."""

    contains('schooltool.courseinfo.interfaces.ICourseInfoContainer')
    containers(ICourseInfoSchoolYearContainer)


class ICourseInfoContainer(IContainer):
    """The interface for the container of courseinfo objects."""

    containers(ICourseInfoSchoolYear)


class ICurrentCourseInfoContainer(ICourseInfoContainer):
    """ The interface for the container of current schoolyear courseinfo objects"""
    contains('schooltool.courseinfo.interfaces.ICurrentCourseInfo')


class IProposedCourseInfoContainer(ICourseInfoContainer):
    """ The interface for the container of the next schoolyear's courseinfo objects"""
    contains('schooltool.courseinfo.interfaces.IProposedCourseInfo')


class CourseInfoValueList(List):
    """Marker field for course info list fields."""


class ICourseInfo(IContained):
    """The interface for the courseinfo object."""

    course_id = TextLine(
        title=u"Locally used course identifier",
        )

    title = TextLine(
        title=u"Course title",
        )

    description = Text(
        title=u"Description",
        )

    start_grade = Int(
        title=u"Start grade",
        )

    end_grade = Int(
        title=u"End grade",
        )

    duration = Int(
        title=u"Duration",
        )

    credits = Float(
        title=u"Credits",
        )

    elective = Bool(
        title=u"Elective",
        )

    division = TextLine(
        title=u"Division",
        )

    cluster = TextLine(
        title=u"Cluster",
        required=False,
        )

    pathway = TextLine(
        title=u"Pathway",
        required=False,
        )

    requirements = CourseInfoValueList(
        title=_("Requirements"),
        value_type=TextLine(title=u"Requirement"),
        required=False,
        )

    government_id = TextLine(
        title=u"Government ID",
        required=False,
        )

    credit_codes = CourseInfoValueList(
        title=_("Credit codes"),
        value_type=TextLine(title=u"Credit code"),
        )

    supervisor = TextLine(
        title=u"Supervisor",
        required=False,
        )

    planning_information = CourseInfoValueList(
        title=_("Planning information"),
        value_type=TextLine(title=u"Planning information line"),
        required=False,
        )

    weight = Float(
        title=u"Weight",
        required=False,
        )

    lab_fee = Float(
        title=u"Lab fee",
        required=False,
        )

    notes = Text(
        title=u"Notes",
        required=False,
        )

    prerequisite = Text(
        title=u"Prerequisite",
        required=False,
        )

    outcomes = Text(
        title=u"Outcomes",
        required=False,
        )


class ICurrentCourseInfo(ICourseInfo):
    """ The interface for a courseinfo object in the current school year. """

    containers(ICurrentCourseInfoContainer)


class IProposedCourseInfo(ICourseInfo):
    """ The interface for a courseinfo object in the next school year. """

    containers(IProposedCourseInfoContainer)
